/* See LICENSE file for copyright and license details. */

/* appearance */
static const int startwithgaps[]    = { 1 };	/* 1 means gaps are used by default, this can be customized for each tag */
static const unsigned int gappx[]   = { 10 };   /* default gap between windows in pixels, this can be customized for each tag */
static const unsigned int borderpx  = 2;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "mononoki Nerd Font:size=12" };
static const char dmenufont[]       = "mononoki Nerd Font:size=12";
static const char col_gray1[]       = "#2e3440";
static const char col_gray2[]       = "#434c5e";
static const char col_gray3[]       = "#d8dee9";
static const char col_gray4[]       = "#eceff4";
static const char col_cyan[]        = "#bf616a";
static const char *colors[][3]      = {
	/*               fg         bg         border   */
	[SchemeNorm] = { col_gray3, col_gray1, col_gray2 },
	[SchemeSel]  = { col_gray4, col_cyan,  col_cyan  },
};

/* tagging */
static const char *tags[] = { "www", "{}", "[/]", "(~)", "|V|", ">_" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance          title       tags mask     isfloating   monitor */
	{ "Gimp",				NULL,           NULL,       0,            1,           -1 },
	{ "Alacritty",	"pulsemixer",   NULL,       0,            1,           -1 },
	{ "Pavucontrol",NULL,           NULL,       0,            1,           -1 },
	{ "Nitrogen",   NULL,           NULL,       0,            1,           -1 },
	{ "Firefox",    NULL,           NULL,       1 << 8,       0,           -1 },
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[]=",      tile },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
	{ "[M]",      monocle },
};

/* key definitions */
#define MODKEY Mod4Mask
#define ALTKEY Mod1Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { "rofi","-show", "drun", NULL };
static const char *rofirun[] = { "rofi","-show", "run", NULL };
static const char *termcmd[]  = { "alacritty", NULL };
static const char *rofipass[]  = { "rofi-pass", NULL };
static const char *browser[]  = { "firefox", NULL };
static const char *screenshot[]  = { "flameshot","gui", NULL };
static const char *files[]  = { "thunar", NULL };
static const char *qpost[]  = { "qpost", NULL };
static const char *pulsemixer[]  = { "alacritty","--class","pulsemixer","-e","pulsemixer",NULL };
static const char *brightup[]  = { "brightnessctl", "set", "+15", NULL };
static const char *brightdown[]  = { "brightnessctl", "set", "15-", NULL };


#include "shift-tools.c"
#include "movestack.c"
#include "X11/XF86keysym.h"
static const Key keys[] = {
	/* modifier                     key        function        argument */
	{ MODKEY,                       XK_p,      spawn,          {.v = dmenucmd } },
	{ MODKEY,                       XK_r,      spawn,          {.v = rofirun } },
	{ MODKEY,                       XK_Return, spawn,          {.v = termcmd } },
	{ MODKEY|ShiftMask,             XK_o,	shiftview,         { .i = +1 } },
	{ MODKEY|ShiftMask,             XK_i,	shiftview,         { .i = -1 } },
	{ MODKEY,                       XK_Right,   shiftview,    { .i = +1 } },
	{ MODKEY,	                    XK_Left,   shiftview,    { .i = -1 } },
	{ MODKEY,                       XK_b,      togglebar,      {0} },
	{ MODKEY,                       XK_j,      focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_k,      focusstack,     {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_j,      movestack,      {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_k,      movestack,      {.i = -1 } },
	{ MODKEY,                       XK_i,      incnmaster,     {.i = +1 } },
	{ MODKEY,                       XK_d,      incnmaster,     {.i = -1 } },
	{ MODKEY,                       XK_h,      setmfact,       {.f = -0.05} },
	{ MODKEY,                       XK_l,      setmfact,       {.f = +0.05} },
	{ MODKEY|ShiftMask,             XK_Return, zoom,           {0} },
	{ MODKEY,                       XK_Tab,    view,           {0} },
	{ MODKEY,                       XK_q,      killclient,     {0} },
	{ MODKEY,                       XK_t,      setlayout,      {.v = &layouts[0]} },
	{ MODKEY,                       XK_f,      setlayout,      {.v = &layouts[1]} },
	{ MODKEY,                       XK_m,      setlayout,      {.v = &layouts[2]} },
	{ MODKEY,                       XK_space,  setlayout,      {0} },
	{ MODKEY|ShiftMask,		        XK_Left,      shiftboth,      { .i = -1 }	},
	//{ MODKEY|ControlMask,		    XK_Left,      shiftswaptags,  { .i = -1 }	},
	//{ MODKEY|ControlMask,		    XK_Right,     shiftswaptags,  { .i = +1 }	},
	{ MODKEY|ShiftMask,             XK_Right,      shiftboth,      { .i = +1 }	},
	{ MODKEY|ShiftMask,             XK_space,  togglefloating, {0} },
	{ MODKEY,                       XK_0,      view,           {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_0,      tag,            {.ui = ~0 } },
	{ MODKEY,                       XK_comma,  focusmon,       {.i = -1 } },
	{ MODKEY,                       XK_period, focusmon,       {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_period, tagmon,         {.i = +1 } },
	//{ MODKEY|ShiftMask,             XK_h,      setgaps,        {.i = -5 } },
	//{ MODKEY|ShiftMask,             XK_l,      setgaps,        {.i = +5 } },
	//{ MODKEY|ShiftMask,             XK_minus,  setgaps,        {.i = GAP_RESET } },
	//{ MODKEY|ShiftMask,             XK_equal,  setgaps,        {.i = GAP_TOGGLE} },
	//{ MODKEY,                       XK_s,      movecenter,     {0} },
	// CUSTOM USER PROGRAMS
	{ MODKEY|ALTKEY,                XK_k,      spawn,          {.v = rofipass } },
	{ MODKEY|ALTKEY,                XK_b,      spawn,          {.v = browser } },
	{ MODKEY|ALTKEY,                XK_f,      spawn,          {.v = files } },
	{ MODKEY|ALTKEY,                XK_p,      spawn,          {.v = qpost } },
	{ MODKEY|ALTKEY,                XK_v,      spawn,          {.v = pulsemixer } },
	{ MODKEY|ShiftMask,             XK_s,      spawn,          {.v = screenshot } },
	{ 0 ,                           XF86XK_MonBrightnessUp,      spawn,          {.v = brightup} },
	{ 0 ,                           XF86XK_MonBrightnessDown,    spawn,          {.v = brightdown} },

	TAGKEYS(                        XK_1,                      0)
	TAGKEYS(                        XK_2,                      1)
	TAGKEYS(                        XK_3,                      2)
	TAGKEYS(                        XK_4,                      3)
	TAGKEYS(                        XK_5,                      4)
	TAGKEYS(                        XK_6,                      5)
	{ MODKEY|ShiftMask,             XK_q,      quit,           {0} },
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};
